Package: RobStatTM
Version: 1.0.11
Date: 2024-10-16
Title: Robust Statistics: Theory and Methods
Authors@R: c(person("Matias", "Salibian-Barrera", role = c("cre"), email = "matias@stat.ubc.ca"),
             person("Victor", "Yohai", role = "aut", email = "vyohai@gmail.com"),
             person("Ricardo", "Maronna", role="aut", email= "rmaronna@retina.ar"),
             person("Doug", "Martin", role="aut", email="martinrd3d@gmail.com"),
             person("Gregory", "Brownson", role="aut", email="gregory.brownson@gmail.com", comment="ShinyUI"),
             person("Kjell", "Konis", role="aut", email="kjellk@gmail.com"),
             person("Kjell", "Konis", role="cph", email="kjellk@gmail.com", comment="erfi"),
             person("Christophe", "Croux", role="ctb", email="christophe.croux@edhec.edu", comment="WBYlogreg, BYlogreg"),
             person("Gentiane", "Haesbroeck", role="ctb", email="G.Haesbroeck@uliege.be", comment="WBYlogreg, BYlogreg"),
             person("Martin", "Maechler", role="cph", email="maechler@stat.math.ethz.ch", comment="lmrob.fit, lmrob..M..fit, lmrob.S"),
             person("Manuel", "Koller", role="cph", email="koller.manuel@gmail.com", comment="lmrob.fit, .vcov.avar1, lmrob.S, lmrob.lar"),
             person("Matias", "Salibian-Barrera", role="aut", email="matias@stat.ubc.ca")
            )
Description: Companion package for the book: "Robust Statistics: Theory and Methods, second edition", <http://www.wiley.com/go/maronna/robust>.  This package contains code that implements the robust estimators discussed in the recent second edition of the book above, as well as the scripts reproducing all the examples in the book.
Depends: R (>= 3.5.0)
Imports: stats, pyinit, rrcov, robustbase
Suggests: R.rsp
LazyData: yes
License: GPL (>= 3)
RoxygenNote: 7.3.2
Encoding: UTF-8
VignetteBuilder: R.rsp
NeedsCompilation: yes
Packaged: 2024-10-16 21:49:21 UTC; msali
Author: Matias Salibian-Barrera [cre],
  Victor Yohai [aut],
  Ricardo Maronna [aut],
  Doug Martin [aut],
  Gregory Brownson [aut] (ShinyUI),
  Kjell Konis [aut],
  Kjell Konis [cph] (erfi),
  Christophe Croux [ctb] (WBYlogreg, BYlogreg),
  Gentiane Haesbroeck [ctb] (WBYlogreg, BYlogreg),
  Martin Maechler [cph] (lmrob.fit, lmrob..M..fit, lmrob.S),
  Manuel Koller [cph] (lmrob.fit, .vcov.avar1, lmrob.S, lmrob.lar),
  Matias Salibian-Barrera [aut]
Maintainer: Matias Salibian-Barrera <matias@stat.ubc.ca>
Repository: CRAN
Date/Publication: 2024-10-17 16:30:08 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 03:27:10 UTC; unix
Archs: RobStatTM.so.dSYM
