# Generated by roxygen2: do not edit by hand

S3method(drop1,lmrobdetMM)
S3method(hatvalues,lmrob)
S3method(print,lmrobdetMM)
S3method(print,prcompRob)
S3method(print,summary.covClassic)
S3method(print,summary.covRob)
S3method(print,summary.lmrobdetMM)
S3method(print,summary.prcompRob)
S3method(summary,covClassic)
S3method(summary,covRob)
S3method(summary,lmrobdetMM)
S3method(summary,prcompRob)
export(BYlogreg)
export(DCML)
export(INVTR2)
export(KurtSDNew)
export(MLocDis)
export(MMPY)
export(MMultiSHR)
export(Multirobu)
export(RockeMulti)
export(SMPCA)
export(SMPY)
export(WBYlogreg)
export(WMLlogreg)
export(bisquare)
export(cov.dcml)
export(covClassic)
export(covRob)
export(covRobMM)
export(covRobRocke)
export(fastmve)
export(huber)
export(initPP)
export(lmrobM)
export(lmrobM.control)
export(lmrobdet.control)
export(lmrobdetDCML)
export(lmrobdetLinTest)
export(lmrobdetMM)
export(lmrobdetMM.RFPE)
export(locScaleM)
export(logregBY)
export(logregWBY)
export(logregWML)
export(mopt)
export(moptv0)
export(opt)
export(optv0)
export(pcaRobS)
export(prcompRob)
export(refine.sm)
export(rho)
export(rhoprime)
export(rhoprime2)
export(rob.linear.test)
export(scaleM)
export(step.lmrobdetMM)
import(stats)
useDynLib(RobStatTM, .registration = TRUE)
